<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation>يرجى تسجيل الدخول باستخدام معرف Deepin الخاص بك.</translation>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation>تحتاج إلى تسجيل الدخول لمتابعة والقيام  بالعمليات اللاحقة.</translation>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation>لقد تم تقديم الكثير من الطلبات، الرجاء إعادة المحاولة لاحقاً.</translation>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation>تحتاج إلى تسجيل الدخول لمتابعة والقيام  بالعمليات اللاحقة.</translation>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation>خطأ في الشبكة ، الرجاء المحاولة لاحقاً.</translation>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>Unlogged</source>
        <translation>غير مسجل</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>مفضلتي</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>إفاداتي</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>تسجيل الخروج</translation>
    </message>
    <message>
        <source>Sign in</source>
        <translation>تسجيل الدخول</translation>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation>%1 وجهات نظر</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>مقترحات</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>غير المفضل</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>المفضلة</translation>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation>إلغاء الرغبة</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>الإلحاح</translation>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>المجيء</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation>الإفادة الرسمية</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation>بحث</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>النوع:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>الكل</translation>
    </message>
    <message>
        <source>Bug</source>
        <translation>خطأ أو مشكلة</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>مقترحات</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>الإصدار:</translation>
    </message>
    <message>
        <source>Sort:</source>
        <translation>فرز:</translation>
    </message>
    <message>
        <source>Newest</source>
        <translation>أحدث</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>المفضلة</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>الإلحاح</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>التواصل</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>تناقش وشارك هنا</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>تقرير الأخطاء</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>الإبلاغ عن المشاكل أو الأخطاء التي عثرت عليها</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>مقترحات</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>إرسال مقترحاتك</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>الموارد</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>الإستبيان</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>انضم إلينا</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>الاختبار الداخلي</translation>
    </message>
    <message>
        <source>Global Translation</source>
        <translation>الترجمة العالمية</translation>
    </message>
    <message>
        <source>Community News</source>
        <translation>أخبار المجتمع</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>No more items</source>
        <translation>لا مزيد من العناصر</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>رسائل</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>الاستبيانات</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>الإطلاق عند بدء التشغيل النظام</translation>
    </message>
    <message>
        <source>About</source>
        <translation>حول</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>خروج</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>منزل Deepin</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation>تسجيل الدخول السريع إلى المنتديات، تقديم الاقتراحات وتقرير الأخطاء.</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>لا توجد رسائل حتى الآن.</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1 رسائل</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>وضع علامة مقروءة على الكل</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>عرض المزيد</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation>خطأ في الشبكة ، الرجاء المحاولة لاحقاً</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>تحديث</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>منزل Deepin</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>لا توجد استبيانات حتى الآن</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>مختصر في: %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>املأ</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation>مازالت معلقة</translation>
    </message>
    <message>
        <source>Reproducing</source>
        <translation>يتكرر</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>مؤكدة</translation>
    </message>
    <message>
        <source>Replied</source>
        <translation>تم الرد</translation>
    </message>
    <message>
        <source>Resolved</source>
        <translation>تمت المعالجة</translation>
    </message>
    <message>
        <source>Evaluating</source>
        <translation>تحت التقييم</translation>
    </message>
    <message>
        <source>Accepted</source>
        <translation>مقبولة</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>مكتملة</translation>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation>لم يتم معالجة المشكلة ولن يتم عرضها في القائمة العامة.</translation>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation>لا يمكن التعرف على السبب حاليًا؛ يتطلب الأمر المراقبة والتحقيق بشكل متواصل.</translation>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation>تم إعادة إنتاج المشكلة وتم التعرف على السبب الجذري.</translation>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation>المشكلة ليست خللًا أو نوعًا مختلفًا.</translation>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation>تم حل المشكلة وينتظر الإصدار الرسمي</translation>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation>&gt; - لم يتم معالجة المتطلب ولم يتم عرضه في القائمة العامة</translation>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation>تم التعرف على المشكلة ويجري تقييمها داخليًا</translation>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation>مدرج ضمن الخطط المقبلة للإصدار</translation>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation>إما أن الشرط غير مقبول أو غير قادر على التلبية</translation>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation>انتهت أعمال التطوير، ويجري الإنتظار للإصدار الرسمي</translation>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation>غير قادر على إضافة لقطة شاشة.</translation>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation>يجب أن يكون حجم ملف الصورة أقل من 1 ميغابايت.</translation>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation>صيغة ملف الصورة غير مدعوم للرفع.</translation>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation>|- [الحالة الحالية للمنتج]: |- [المنتج المرغوب]: |</translation>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation>|- [الشروط المسبقة]: |- [خطوات التجددية]: |- [النتائج المتوقعة]: |- [النتائج الفعلية]: |</translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>إرسال الإفادة</translation>
    </message>
    <message>
        <source>Type：</source>
        <translation>النوع:</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>مقترحات</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>تقرير الأخطاء</translation>
    </message>
    <message>
        <source>Title：</source>
        <translation>العنوان:</translation>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation>الرجاء تقديم وصف موجز لمشكلتك</translation>
    </message>
    <message>
        <source>Content：</source>
        <translation>المحتوى:</translation>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation>لا تدخل عدة مشاكل في ملاحظة واحدة</translation>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation>لا تدخل عدة متطلبات في ملاحظة واحدة</translation>
    </message>
    <message>
        <source>Email：</source>
        <translation>البريد الإلكتروني:</translation>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation>الرجاء إدخال عنوان بريدك الإلكتروني</translation>
    </message>
    <message>
        <source>System Version:</source>
        <translation>رقم إصدار النظام:</translation>
    </message>
    <message>
        <source>Device Info：</source>
        <translation>معلومات الجهاز:</translation>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation>رفع &lt;a href=&apos;home://sysinfo&apos;&gt;معلومات الجهاز&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation>لقطات الشاشة:</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>ملفات الصور</translation>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation>قم بسحب الملفات وإفلاتها أو انقر فوق الأزرار لإضافة صور  (حتى ثلاثة ملفات أو صور)</translation>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation>هل أنت متأكد من رغبتك في الخروج من معالج إرسال الإفادات؟</translation>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation>لن يتم حفظ محتوى الإفادة.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>خروج</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>إرسال</translation>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation>غير قادر على إرسال الإفادة.</translation>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation>الرجاء تقديم عنوان ومحتوى لإفادتك.</translation>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation>الرجاء تقديم عنوان لإفادتك.</translation>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation>الرجاء تقديم محتوى لإفادتك.</translation>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation>تم إدخال عنوان بريد إلكتروني غير صحيح.</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>معلومات الجهاز</translation>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation>مركز الملاحظات</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>إفاداتي</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>مفضلتي</translation>
    </message>
    <message>
        <source>My Urged</source>
        <translation>مطلوباتي</translation>
    </message>
</context>
</TS>